@@ -20,6 +20,8 @@
  ***************************************************************************/
 #include <QHeaderView>
 #include <QFileInfo>
+#include <QDropEvent>
+#include <QDragEnterEvent>
 #include <QSortFilterProxyModel>
 #include <krun.h>
 #include <kmenu.h>
@@ -30,6 +32,7 @@
 #include <kinputdialog.h>
 #include <interfaces/torrentinterface.h>
 #include <torrent/queuemanager.h>
+#include <torrent/jobqueue.h>
 #include <util/functions.h>
 #include <util/log.h>
 #include <interfaces/functions.h>
@@ -42,7 +45,8 @@
 #include "speedlimitsdlg.h"
 #include "addpeersdlg.h"
 #include "viewselectionmodel.h"
-
+#include "viewdelegate.h"
+#include "scanlistener.h"
 
 using namespace bt;
 
@@ -62,11 +66,10 @@ namespace kt
 		setDragEnabled(true);
 		setSelectionMode(QAbstractItemView::ExtendedSelection);
 		setSelectionBehavior(QAbstractItemView::SelectRows);
-		setUniformRowHeights(true);
+		setAcceptDrops(true);
+		setDragDropMode(DragDrop);
+//		setUniformRowHeights(true);
 		
-		connect(this,SIGNAL(wantToRemove(bt::TorrentInterface*,bool )),core,SLOT(remove(bt::TorrentInterface*,bool )));
-		connect(this,SIGNAL(wantToStart( QList<bt::TorrentInterface*> & )),core,SLOT(start( QList<bt::TorrentInterface*> & )));
-		connect(this,SIGNAL(wantToStop( bt::TorrentInterface*, bool )),core,SLOT(stop( bt::TorrentInterface*, bool )));
 		connect(this,SIGNAL(customContextMenuRequested(const QPoint & ) ),this,SLOT(showMenu( const QPoint& )));
 	
 		header()->setContextMenuPolicy(Qt::CustomContextMenu);
@@ -97,10 +100,14 @@ namespace kt
 		connect(selectionModel(),SIGNAL(selectionChanged(const QItemSelection &,const QItemSelection)),
 				this,SLOT(onSelectionChanged(const QItemSelection &,const QItemSelection)));
 		connect(model,SIGNAL(sorted()),selection_model,SLOT(sorted()));
+		
+		delegate = new ViewDelegate(core,model,this);
+		setItemDelegate(delegate);
 	}
 
 	View::~View()
 	{
+		delegate->contractAll();
 	}
 	
 	void View::setupDefaultColumns()
@@ -131,7 +138,7 @@ namespace kt
 
 	void View::update()
 	{
-		model->update();
+		model->update(delegate);
 	}
 
 	bool View::needToUpdateCaption()
@@ -175,17 +182,16 @@ namespace kt
 	{
 		QList<bt::TorrentInterface*> sel;
 		getSelection(sel);
-		wantToStart(sel);
+		if (sel.count() > 0)
+			core->start(sel);
 	}
 
 	void View::stopTorrents()
 	{
 		QList<bt::TorrentInterface*> sel;
 		getSelection(sel);
-		foreach(bt::TorrentInterface* tc,sel)
-		{
-			wantToStop(tc,true);
-		}
+		if (sel.count() > 0)
+			core->stop(sel);
 	}
 
 	void View::removeTorrents()
@@ -194,8 +200,7 @@ namespace kt
 		getSelection(sel);
 		foreach(bt::TorrentInterface* tc,sel)
 		{
-			bool dummy;
-			if (tc && !tc->isCheckingData(dummy))
+			if (tc && !tc->getJobQueue()->runningJobs())
 			{	
 				const TorrentStats & s = tc->getStats();
 				bool data_to = false;
@@ -215,7 +220,7 @@ namespace kt
 					else if (ret == KMessageBox::Yes)
 						data_to = true;
 				}
-				wantToRemove(tc,data_to);
+				core->remove(tc,data_to);
 			}
 		}
 	}
@@ -233,9 +238,8 @@ namespace kt
 
 		foreach(bt::TorrentInterface* tc,sel)
 		{
-			bool dummy = false;
-			if (tc && !tc->isCheckingData(dummy))
-				wantToRemove(tc,true);
+			if (tc && !tc->getJobQueue()->runningJobs())
+				core->remove(tc,true);
 		}
 	}
 
@@ -243,29 +247,14 @@ namespace kt
 	{
 		QList<bt::TorrentInterface*> all;
 		model->allTorrents(all);
-		wantToStart(all);
+		core->start(all);
 	}
 
 	void View::stopAllTorrents()
 	{
 		QList<bt::TorrentInterface*> all;
 		model->allTorrents(all);
-		foreach (bt::TorrentInterface* tc,all)
-		{
-			wantToStop(tc,true);
-		}
-	}
-
-	void View::queueTorrents()
-	{
-		QList<bt::TorrentInterface*> sel;
-		getSelection(sel);
-		foreach(bt::TorrentInterface* tc,sel)
-		{
-			bool dummy;
-			if (tc && !tc->isCheckingData(dummy))
-				core->queue(tc);
-		}
+		core->stop(all);
 	}
 
 	void View::addPeers()
@@ -374,13 +363,12 @@ namespace kt
 		getSelection(sel);
 		foreach(bt::TorrentInterface* tc,sel)
 		{
-			bool dummy;
-			if (tc && !tc->isCheckingData(dummy))
+			if (tc)
 			{
 				bool on = tc->isFeatureEnabled(bt::DHT_FEATURE);
 				tc->setFeatureEnabled(bt::DHT_FEATURE,!on);
 			}
-		}							
+		}
 	}
 
 	void View::togglePEX()
@@ -389,8 +377,7 @@ namespace kt
 		getSelection(sel);
 		foreach(bt::TorrentInterface* tc,sel)
 		{
-			bool dummy;
-			if (tc && !tc->isCheckingData(dummy))
+			if (tc)
 			{
 				bool on = tc->isFeatureEnabled(bt::UT_PEX_FEATURE);
 				tc->setFeatureEnabled(bt::UT_PEX_FEATURE,!on);
@@ -413,18 +400,35 @@ namespace kt
 	{
 		QList<bt::TorrentInterface*> sel;
 		getSelection(sel);
-		if (sel.count() == 0)
+		if (sel.count() > 0)
+		{
+			core->doDataCheck(sel.front());
+			core->startUpdateTimer(); // make sure update timer of core is running
+		}
+	}
+
+	void View::dataScanStarted(ScanListener* listener)
+	{
+		if (delegate->extended(listener->torrent()))
 			return;
 		
-		ScanDlg* dlg = new ScanDlg(core,false,this);
-		dlg->show();
-		dlg->execute(sel.front(),false);
-		core->startUpdateTimer(); // make sure update timer of core is running
+		QWidget* ext = listener->createExtender();
+		if (ext)
+		{
+			ext->hide();
+			delegate->extend(listener->torrent(),ext);
+		}
 	}
+	
+	void View::dataScanClosed(ScanListener* listener)
+	{
+		delegate->closeExtender(listener->torrent());
+	}
+
 
 	void View::showMenu(const QPoint & pos)
 	{
-		showMenu(this,mapToGlobal(pos));
+		showMenu(this,viewport()->mapToGlobal(pos));
 	}
 	
 	void View::showHeaderMenu(const QPoint& pos)
@@ -514,6 +518,8 @@ namespace kt
 		
 		return ret;
 	}
+
+	
 }
 
 #include "view.moc"
