@@ -20,14 +20,15 @@
 #ifndef KTSCANFOLDERPLUGIN_H
 #define KTSCANFOLDERPLUGIN_H
 
+#include <util/ptrmap.h>
 #include <interfaces/plugin.h>
+#include "scanfolder.h"
 
 class QString;
 
 
 namespace kt
 {	
-	class ScanFolder;
 	class ScanFolderPrefPage;
 	
 	/**
@@ -39,21 +40,19 @@ namespace kt
 	{
 		Q_OBJECT
 	public:
-		ScanFolderPlugin(QObject* parent, const char* name, const QStringList& args);
+		ScanFolderPlugin(QObject* parent, const QStringList& args);
 		virtual ~ScanFolderPlugin();
 
 		virtual void load();
 		virtual void unload();
 		virtual bool versionCheck(const QString& version) const;
 		
+	public slots:
 		void updateScanFolders();
 		
-		private:
-			ScanFolder* m_sf1;
-			ScanFolder* m_sf2;
-			ScanFolder* m_sf3;
-			
-			ScanFolderPrefPage* pref;
+	private:
+		bt::PtrMap<QString,ScanFolder> m_sf_map;
+		ScanFolderPrefPage* pref;
 	};
 
 }
