@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2005 by Joris Guisson                                   *
+ *   Copyright (C) 2005-2007 by Joris Guisson                              *
  *   joris.guisson@gmail.com                                               *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -15,36 +15,37 @@
  *   You should have received a copy of the GNU General Public License     *
  *   along with this program; if not, write to the                         *
  *   Free Software Foundation, Inc.,                                       *
- *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.             *
+ *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.          *
  ***************************************************************************/
 #ifndef KTSEARCHPREFPAGE_H
 #define KTSEARCHPREFPAGE_H
 
-
-#include <interfaces/prefpageinterface.h>
-#include "searchpref.h"
-
 #include <qstring.h>
+#include <interfaces/prefpageinterface.h>
+#include "ui_searchpref.h"
+
 
 namespace kt
 {	
 	class SearchPlugin;
 	class SearchEngineList;
 	
-	class SearchPrefPageWidget : public SEPreferences
+	/**
+	 * @author Joris Guisson
+	 *
+	 * Preference page for the search plugin.
+	*/
+	class SearchPrefPage : public PrefPageInterface,public Ui_SearchPref
 	{
 		Q_OBJECT
 	public:
-		SearchPrefPageWidget(QWidget *parent = 0);
-	
-		bool apply();
-		void saveSearchEngines();
-		void updateList(QString& source);
+		SearchPrefPage(SearchPlugin* plugin,SearchEngineList* sl,QWidget* parent);
+		virtual ~SearchPrefPage();
 		
-		void updateSearchEngines(const SearchEngineList & se);
+		virtual void loadSettings();
+		virtual void loadDefaults();
 		
 	public slots:
-		virtual void btnUpdate_clicked();
 		void customToggled(bool toggled);
 	
 	private slots:
@@ -52,25 +53,17 @@ namespace kt
 		void removeClicked();
 		void addDefaultClicked();
 		void removeAllClicked();
-	}; 
-
-	/**
-	@author Joris Guisson
-	*/
-	class SearchPrefPage : public PrefPageInterface
-	{
-	public:
-		SearchPrefPage(SearchPlugin* plugin);
-		virtual ~SearchPrefPage();
-
-		virtual bool apply();
-		virtual void createWidget(QWidget* parent);
-		virtual void updateData();
-		virtual void deleteWidget();
+		void clearHistory();
+		void openInExternalToggled(bool on);
+		void selectionChanged(const QItemSelection & selected,const QItemSelection & deselected);
+		void downloadJobFinished(KJob* j);
 
+	signals:
+		void clearSearchHistory();
+	
 	private:
-		SearchPrefPageWidget* widget;
-		SearchPlugin* m_plugin;
+		SearchPlugin* plugin;
+		SearchEngineList* engines;
 	};
 
 }
